@@ -4,9 +4,9 @@ use warnings;
 use base qw( SWISH::Prog::Results );
 use SWISH::Prog::Xapian::Result;
 
-__PACKAGE__->mk_ro_accessors(qw( mset ));
+__PACKAGE__->mk_ro_accessors(qw( mset prop_id_map ));
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 =head1 NAME
 
@@ -30,6 +30,10 @@ the L<SWISH::Prog::Results> documentation.
 Get the internal Search::Xapian::MSet object. This is a read-only
 accessor method.
 
+=head2 prop_id_map 
+
+Get the read-only internal map for PropertyNames to id values.
+
 =head2 next
 
 Returns the next SWISH::Prog::Xapian::Result from the Results iterator.
@@ -42,8 +46,9 @@ sub next {
     return if $i >= $self->hits;
     my $mit = $self->{mset}->get_msetiterator($i);
     return SWISH::Prog::Xapian::Result->new(
-        doc   => $mit->get_document(),
-        score => $mit->get_percent() * 10,    # scale to 1000
+        prop_id_map => $self->{prop_id_map},
+        doc          => $mit->get_document(),
+        score        => $mit->get_percent() * 10,    # scale to 1000
     );
 }
 
